:orphan:

.. include:: _contributors.rst
.. currentmodule:: treeple

.. _v0_2:

Version 0.2
===========

This release is a major release, with many new features and improvements.
For instance, we have added a new implementation of the extended isolation forest,
enabled all decision trees to take advantage of ``partial_fit`` meaning trees have streaming
capabilities. Moreover, we have added an analogous implementation of extra-trees for oblique-trees.
Finally, this release includes a highly experimental feature for multivariate high-dimensional
hypothesis testing using permutation forests and a feature importance testing forest.

Changelog
---------
- |Efficiency| Upgraded build process to rely on Cython 3.0+, by `Adam Li`_  (:pr:`109`)
- |Feature| Allow decision trees to take advantage of ``partial_fit`` and ``monotonic_cst`` when available, by `Adam Li`_  (:pr:`109`)
- |Feature| Implementation of  ExtraObliqueDecisionTreeClassifier, ExtraObliqueDecisionTreeRegressor by `SUKI-O`_ (:pr:`75`)
- |Efficiency| Around 1.5-2x speed improvement for unsupervised forests, by `Adam Li`_  (:pr:`114`)
- |API| Allow ``sqrt`` and ``log2`` keywords to be used for ``min_samples_split`` parameter in unsupervised forests, by `Adam Li`_  (:pr:`114`)
- |Feature| Implement extended isolation forest, by `Adam Li`_ (:pr:`101`)
- |Feature| Implementation of StreamDecisionForest, by `Haoyin Xu`_ and `Adam Li`_ (:pr:`116`)
- |Feature| Implementation of Permutation forests and a feature importance testing forest, by `Haoyin Xu`_, `Adam Li`_, `Sambit Panda`_ (:pr:`125`)

Code and Documentation Contributors
-----------------------------------

Thanks to everyone who has contributed to the maintenance and improvement of
the project since version inception, including:

* `Adam Li`_
* `SUKI-O`_
* `Haoyin Xu`_
* `Sambit Panda`_
